# SEC11-BP04: Maintain security properties of pipelines

## Description

Shared security services.

## Implementation Guidance

- Secure CI/CD pipelines
- Artifact signing
- Pipeline access controls
- Build reproducibility
- Supply chain security

## Risk Level

High - Compromised pipelines affect all deployments.
